[FFmpeg-soc] [soc]: r1574 - in eac3: eac3.h eac3dec.c

jbr subversion at mplayerhq.hu
Fri Dec 14 08:04:09 CET 2007


Author: jbr
Date: Fri Dec 14 08:04:09 2007
New Revision: 1574

Log:
remove 2 unused variables

Modified:
   eac3/eac3.h
   eac3/eac3dec.c

Modified: eac3/eac3.h
==============================================================================
--- eac3/eac3.h	(original)
+++ eac3/eac3.h	Fri Dec 14 08:04:09 2007
@@ -52,8 +52,6 @@ typedef struct EAC3Context{
     int lfe_on;                      ///< Low frequency effect channel on (lfeon)
     int bitstream_id;                ///< Bit stream identification (bsid)
     float dialog_norm[2];            ///< Dialogue normalization (dialnorm)
-    int pgmscl[2];                   ///< Program scale factor
-    int extpgmscl;                   ///< External program scale factor
     int mixdef;                      ///< Mix control type
     int mixdeflen;                   ///< Length of mixing parameter data field
     int paninfo[2];                  ///< Pan information

Modified: eac3/eac3dec.c
==============================================================================
--- eac3/eac3dec.c	(original)
+++ eac3/eac3dec.c	Fri Dec 14 08:04:09 2007
@@ -440,14 +440,13 @@ static int parse_bsi(GetBitContext *gbc,
         }
         if (s->stream_type == EAC3_STREAM_TYPE_INDEPENDENT) {
             for (i = 0; i < (s->channel_mode ? 1 : 2); i++) {
+                // TODO: apply program scale factor
                 if (get_bits1(gbc)) {
-                    s->pgmscl[i] = get_bits(gbc, 6);
-                } else {
-                    //TODO program scale factor = 0dB
+                    skip_bits(gbc, 6);  // skip program scale factor
                 }
             }
             if (get_bits1(gbc)) {
-                s->extpgmscl = get_bits(gbc, 6);
+                skip_bits(gbc, 6);  // skip external program scale factor
             }
             s->mixdef = get_bits(gbc, 2);
             if (s->mixdef == 1) {



More information about the FFmpeg-soc mailing list